aboutsummaryrefslogtreecommitdiff
path: root/src/modules/m_spanningtree/utils.cpp
diff options
context:
space:
mode:
authorGravatar w00t2007-10-15 21:04:32 +0000
committerGravatar w00t2007-10-15 21:04:32 +0000
commit2b68243097f98ace4a53b21520718874b0ed7db5 (patch)
tree5fbdbb4270efebbfb0956733d25b1245c8586d25 /src/modules/m_spanningtree/utils.cpp
parentInspTimer -> Timer (diff)
InspSocket -> BufferedSocket. Paves the way for a SimpleSocket class which ident etc will use.
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@8206 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'src/modules/m_spanningtree/utils.cpp')
-rw-r--r--src/modules/m_spanningtree/utils.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/modules/m_spanningtree/utils.cpp b/src/modules/m_spanningtree/utils.cpp
index 4814013e6..0376ea0c2 100644
--- a/src/modules/m_spanningtree/utils.cpp
+++ b/src/modules/m_spanningtree/utils.cpp
@@ -181,7 +181,7 @@ SpanningTreeUtilities::SpanningTreeUtilities(InspIRCd* Instance, ModuleSpanningT
this->TreeRoot = new TreeServer(this, ServerInstance, ServerInstance->Config->ServerName, ServerInstance->Config->ServerDesc, ServerInstance->Config->GetSID());
- modulelist* ml = ServerInstance->Modules->FindInterface("InspSocketHook");
+ modulelist* ml = ServerInstance->Modules->FindInterface("BufferedSocketHook");
/* Did we find any modules? */
if (ml)
@@ -190,9 +190,9 @@ SpanningTreeUtilities::SpanningTreeUtilities(InspIRCd* Instance, ModuleSpanningT
for (modulelist::iterator m = ml->begin(); m != ml->end(); m++)
{
/* Make a request to it for its name, its implementing
* InspSocketHook so we know its safe to do this
*/
- std::string name = InspSocketNameRequest((Module*)Creator, *m).Send();
+ std::string name = BufferedSocketNameRequest((Module*)Creator, *m).Send();
/* Build a map of them */
hooks[name.c_str()] = *m;
hooknames.push_back(name);
@@ -220,7 +220,7 @@ SpanningTreeUtilities::~SpanningTreeUtilities()
}
}
delete TreeRoot;
- ServerInstance->InspSocketCull();
+ ServerInstance->BufferedSocketCull();
}
void SpanningTreeUtilities::AddThisServer(TreeServer* server, TreeServerList &list)
@@ -190,9 +190,9 @@ SpanningTreeUtilities::SpanningTreeUtilities(InspIRCd* Instance, ModuleSpanningT
{
/* Make a request to it for its name, its implementing
- * InspSocketHook so we know its safe to do this
+ * BufferedSocketHook so we know its safe to do this
*/